==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/Results.java <==
package com.example.model;

/**
 * Model for Results
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.328Z")
@io.swagger.annotations.ApiModel(value = "Results", description = "Model for Results")
@javax.xml.bind.annotation.XmlRootElement(name = "Results")
public class Results implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String data = null;
	private java.lang.String documents = null;
	private java.lang.String facematch = null;
	private java.lang.String liveness = null;
	private java.lang.String overall = null;
	
	/**
	 */
	public Results data(java.lang.String data) {
		setData(data);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("data")
	@javax.validation.constraints.NotNull
	public java.lang.String getData() {
		return this.data;
	}
	public void setData(java.lang.String data) {
		this.data = data;
	}
	
	/**
	 */
	public Results documents(java.lang.String documents) {
		setDocuments(documents);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("documents")
	public java.lang.String getDocuments() {
		return this.documents;
	}
	public void setDocuments(java.lang.String documents) {
		this.documents = documents;
	}
	
	/**
	 */
	public Results facematch(java.lang.String facematch) {
		setFacematch(facematch);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("facematch")
	public java.lang.String getFacematch() {
		return this.facematch;
	}
	public void setFacematch(java.lang.String facematch) {
		this.facematch = facematch;
	}
	
	/**
	 */
	public Results liveness(java.lang.String liveness) {
		setLiveness(liveness);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("liveness")
	public java.lang.String getLiveness() {
		return this.liveness;
	}
	public void setLiveness(java.lang.String liveness) {
		this.liveness = liveness;
	}
	
	/**
	 */
	public Results overall(java.lang.String overall) {
		setOverall(overall);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("overall")
	public java.lang.String getOverall() {
		return this.overall;
	}
	public void setOverall(java.lang.String overall) {
		this.overall = overall;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		Results results = (Results) o;
		return java.util.Objects.equals(this.data, results.data)
				&& java.util.Objects.equals(this.documents, results.documents)
				&& java.util.Objects.equals(this.facematch, results.facematch)
				&& java.util.Objects.equals(this.liveness, results.liveness)
				&& java.util.Objects.equals(this.overall, results.overall);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.data, this.documents, this.facematch, this.liveness, this.overall);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class Results {\n");
		
		sb.append("    data: ").append(toIndentedString(this.data)).append("\n");
		sb.append("    documents: ").append(toIndentedString(this.documents)).append("\n");
		sb.append("    facematch: ").append(toIndentedString(this.facematch)).append("\n");
		sb.append("    liveness: ").append(toIndentedString(this.liveness)).append("\n");
		sb.append("    overall: ").append(toIndentedString(this.overall)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/Results.java <==
package com.example.model;

/**
 * Model for Results
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.431Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "Results", description = "Model for Results")
@javax.xml.bind.annotation.XmlRootElement(name = "Results")
public class Results implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String data = null;
	private java.lang.String documents = null;
	private java.lang.String facematch = null;
	private java.lang.String liveness = null;
	private java.lang.String overall = null;
	
	/**
	 */
	public Results data(java.lang.String data) {
		setData(data);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "data")
	@com.fasterxml.jackson.annotation.JsonProperty("data")
	@javax.validation.constraints.NotNull
	public java.lang.String getData() {
		return this.data;
	}
	public void setData(java.lang.String data) {
		this.data = data;
	}
	
	/**
	 */
	public Results documents(java.lang.String documents) {
		setDocuments(documents);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "documents")
	@com.fasterxml.jackson.annotation.JsonProperty("documents")
	public java.lang.String getDocuments() {
		return this.documents;
	}
	public void setDocuments(java.lang.String documents) {
		this.documents = documents;
	}
	
	/**
	 */
	public Results facematch(java.lang.String facematch) {
		setFacematch(facematch);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "facematch")
	@com.fasterxml.jackson.annotation.JsonProperty("facematch")
	public java.lang.String getFacematch() {
		return this.facematch;
	}
	public void setFacematch(java.lang.String facematch) {
		this.facematch = facematch;
	}
	
	/**
	 */
	public Results liveness(java.lang.String liveness) {
		setLiveness(liveness);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "liveness")
	@com.fasterxml.jackson.annotation.JsonProperty("liveness")
	public java.lang.String getLiveness() {
		return this.liveness;
	}
	public void setLiveness(java.lang.String liveness) {
		this.liveness = liveness;
	}
	
	/**
	 */
	public Results overall(java.lang.String overall) {
		setOverall(overall);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "overall")
	@com.fasterxml.jackson.annotation.JsonProperty("overall")
	public java.lang.String getOverall() {
		return this.overall;
	}
	public void setOverall(java.lang.String overall) {
		this.overall = overall;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		Results results = (Results) o;
		return java.util.Objects.equals(this.data, results.data)
				&& java.util.Objects.equals(this.documents, results.documents)
				&& java.util.Objects.equals(this.facematch, results.facematch)
				&& java.util.Objects.equals(this.liveness, results.liveness)
				&& java.util.Objects.equals(this.overall, results.overall);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.data, this.documents, this.facematch, this.liveness, this.overall);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class Results {\n");
		
		sb.append("    data: ").append(toIndentedString(this.data)).append("\n");
		sb.append("    documents: ").append(toIndentedString(this.documents)).append("\n");
		sb.append("    facematch: ").append(toIndentedString(this.facematch)).append("\n");
		sb.append("    liveness: ").append(toIndentedString(this.liveness)).append("\n");
		sb.append("    overall: ").append(toIndentedString(this.overall)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
